@@ -1,3 +1,4 @@
+__version__ = '1.1.0'
 __all__ = ["cloud", "collPartner", "composition", "despoticError", \
            "dustProp", "emitter", "emitterData", "fetchLamda", \
            "lineProfLTE", "radiation", "refreshLamda"]
@@ -16,3 +17,4 @@ from fetchLamda import fetchLamda
 from lineProfLTE import lineProfLTE
 from radiation import radiation
 from refreshLamda import refreshLamda
+import chemistry
