@@ -30,6 +30,8 @@ from emitter import emitter
 from composition import composition
 from radiation import radiation
 from dustProp import dustProp
+from despotic.chemistry.chemEvol import chemEvol
+from despotic.chemistry.setChemEq import setChemEq
 from despoticError import despoticError
 from copy import deepcopy
 
@@ -46,7 +48,7 @@ G = physcons.G*1e3
 # Small numerical value
 small = 1e-50
 
-class cloud:
+class cloud(object):
     """
     A class describing the properties of an interstellar cloud, and
     providing methods to perform calculations using those properties.
@@ -76,6 +78,9 @@ class cloud:
     emitters : dict
          keys of the dict are names of emitting species, and values
          are objects of class emitter
+    chemnetwork : chemical network class (optional)
+         a chemical network that is to be used to perform
+         time-dependent chemical evolution calcualtions for this cloud
 
     Methods
     -------
@@ -94,6 +99,9 @@ class cloud:
     lineLum -- return the CMB-subtracted line luminosity / intensity /
          brightness temperature of transitions from the specified
          emitter
+    setChemEq -- set the abundances of species to their chemical
+         equilibrium values
+    chemEvol -- calculate time-dependent chemical evolution
     """
 
 
@@ -140,7 +148,8 @@ class cloud:
 ########################################################################
 # Method to set velocity dispersion to virial value
 ########################################################################
-    def setVirial(self, alphaVir=1.0, setColDen=False, setnH=False):
+    def setVirial(self, alphaVir=1.0, setColDen=False, setnH=False, \
+                      NTonly=False):
         """
         Set sigmaNT, colDen, or nH to the value required to give a
         virial ratio of unity
@@ -155,6 +164,9 @@ class cloud:
         setnH : Boolean
             if True, sigmaNT and colDen are fixed, and nH is altered
             to give the desired virial ratio
+        NTonly : Boolean
+            if True, the virial ratio is computed considering only the
+            non-thermal component of the velocity dispersion
 
         Returns
         -------
@@ -174,7 +186,10 @@ class cloud:
                 " setColDen and setnH"
 
         # Thermal velocity disperison squared
-        sigmaThSqr = kB*self.Tg / (self.comp.mu*mH)
+        if NTonly == False:
+            sigmaThSqr = kB*self.Tg / (self.comp.mu*mH)
+        else:
+            sigmaThSqr = 0.0
 
         # Default case
         if setColDen==False and setnH==False:
@@ -355,19 +370,16 @@ class cloud:
 
             elif linesplit[0].upper().strip() == 'H2OPR':
 
-                opr = float(linesplit2[0])
+                self.comp.H2OPR = float(linesplit2[0])
                 if verbose:
-                    print "Setting H2 ortho-para ratio = "+str(opr)
+                    print "Setting H2 ortho-para ratio = "+str(self.comp.H2OPR)
 
             elif linesplit[0].upper().strip() == 'XH2':
 
-                try:
-                    opr==None
-                except UnboundLocalError:
-                    opr = 0.25
+                self.comp.xH2 = float(linesplit2[0])
+                if self.comp.H2OPR is None:
+                    self.comp.H2OPR = 0.25
                     print("Warning: H2 OPR unspecified, assuming 0.25")
-                self.comp.xpH2 = 1.0/(1.0+opr)*float(linesplit2[0])
-                self.comp.xoH2 = opr/(1.0+opr)*float(linesplit2[0])
                 if verbose:
                     print "Setting xpH2 = "+str(self.comp.xpH2)
                     print "Setting xoH2 = "+str(self.comp.xoH2)
@@ -559,9 +571,9 @@ class cloud:
             produces an error
         """
         self.emitters[emitName] = \
-            emitter(emitName, emitAbundance, \
-                        emitterFile=emitterFile, \
-                        emitterURL=emitterURL, \
+            emitter(emitName, emitAbundance, 
+                        emitterFile=emitterFile, 
+                        emitterURL=emitterURL, 
                         extrap=extrap, energySkip=energySkip)
 
 
@@ -836,7 +848,7 @@ class cloud:
                     rates['GammaDustIR'] = GammaDIR
                 rates['LambdaDust'] = LambdaD
                 if PsiUser != None:
-                    rates['PsiUserRad'] = PsiUserVal[1]
+                    rates['PsiUserDust'] = PsiUserVal[1]
             if gasOnly == False and dustOnly == False and \
                     dustCoolOnly == False:
                 rates['GammaDustLine'] = GammaDLine
@@ -933,7 +945,6 @@ class cloud:
         if noLines == False:
             GammaSum += rates['GammaDustLine']
             GammaSumMax = max(GammaSumMax, rates['GammaDustLine'])
-        lumScale = rates['maxAbsdEdtDust']
 
         # Step 3: if we don't have an initial guess, make one by
         # assuming that dust-gas coupling is negligible, and that the
@@ -945,7 +956,7 @@ class cloud:
                      (1.0/(4.0+self.dust.beta))
 
         # Step 4: get initial scaling
-        rates = cloud.dEdt(dustOnly=True, sumOnly=True, \
+        rates = self.dEdt(dustOnly=True, sumOnly=True, \
                                PsiUser=PsiUser, \
                                fixedLevPop=True, \
                                verbose=verbose)
@@ -964,7 +975,7 @@ class cloud:
         # Check that we're really converged; if not, try again
         # starting from guessed starting position
         if abs(_dustTempResid(self.Td, self, PsiUser, GammaSum, \
-                                  GammaSumMax, False)) > 1.0e-3:
+                                  GammaSumMax, lumScale, False)) > 1.0e-3:
             self.Td = \
                 (GammaSum / \
                      (c*a*self.dust.sigma10*0.1**self.dust.beta)) ** \
@@ -981,7 +992,7 @@ class cloud:
 
         # Test for success and return appropriate value
         if abs(_dustTempResid(self.Td, self, PsiUser, GammaSum, \
-                                  GammaSumMax, False)) > 1.0e-3:
+                                  GammaSumMax, lumScale, False)) > 1.0e-3:
             return False
         else:
             return True
@@ -1517,6 +1528,126 @@ class cloud:
 
 
 
+########################################################################
+# Method to calculate time-dependent evolution of chemical abundances;
+# note that this is just a wrapper routine for
+# despotic.chemistry.chemEvol.setChemEq
+########################################################################
+    def setChemEq(self, tEqGuess=None, network=None, info=None,
+              addEmitters=False, tol=1e-6, maxTime=1e16,
+              verbose=False, convList=None):
+        """
+        Set the chemical abundances for a cloud to their equilibrium
+        values, computed using a specified chemical netowrk.
+
+        Parameters
+        ----------
+        tEqGuess : float
+            a guess at the timescale over which equilibrium will be
+            achieved; if left unspecified, the code will attempt to
+            estimate this time scale on its own
+        network : chemical network class
+            a valid chemical network class; this class must define the
+            methods __init__, dxdt, and applyAbundances; if None, the
+            existing chemical network for the cloud is used
+        info : dict
+            a dict of additional initialization information to be passed
+            to the chemical network class when it is instantiated
+        addEmitters : Boolean
+            if True, emitters that are included in the chemical
+            network but not in the cloud's existing emitter list will
+            be added; if False, abundances of emitters already in the
+            emitter list will be updated, but new emiters will not be
+            added to the cloud
+        tol : float
+            tolerance requirement on the equilibrium solution
+        convList : list
+            list of species to include when calculating tolerances to
+            decide if network is converged; species not listed are not
+            considered. If this is None, then all species are considered
+            in deciding if the calculation is converged.
+        verbose : Boolean
+            if True, diagnostic information is printed as the calculation
+            proceeds
+
+        Returns
+        -------
+        converged : Boolean
+            True if the calculation converged, False if not
+
+        Raises
+        ------
+        despoticError, if network is None and the cloud does not already
+        have a defined chemical network associated with it
+
+        Remarks
+        -------
+        The final abundances are written to the cloud whether or not the
+        calculation converges.
+        """
+
+        return setChemEq(self, tEqGuess=tEqGuess, network=network,
+                         info=info, tol=tol, maxTime=maxTime,
+                         verbose=verbose, convList=convList)
+
+########################################################################
+# Method to calculate time-dependent evolution of chemical abundances;
+# note that this is just a wrapper routine for
+# despotic.chemistry.chemEvol.chemEvol
+########################################################################
+    def chemEvol(self, tFin, tInit=0.0, nOut=100, dt=None,
+                 tOut=None, network=None, info=None,
+                 addEmitters=False):
+        """
+        Evolve the chemical abundances of this cloud in time.
+
+        Parameters
+        ----------
+        tFin : float
+             end time of integration, in sec
+        tInit : float
+             start time of integration, in sec
+        nOut : int
+             number of times at which to report the temperature; this
+             is ignored if dt or tOut are set
+        dt : float
+             time interval between outputs, in sec; this is ignored if
+             tOut is set
+        tOut : array
+             list of times at which to output the temperature, in sec;
+             must be sorted in increasing order
+        network : chemical network class
+             a valid chemical network class; this class must define the
+             methods __init__, dxdt, and applyAbundances; if None, the
+             existing chemical network for the cloud is used
+        info : dict
+             a dict of additional initialization information to be passed
+             to the chemical network class when it is instantiated
+        addEmitters : Boolean
+             if True, emitters that are included in the chemical
+             network but not in the cloud's existing emitter list will
+             be added; if False, abundances of emitters already in the
+             emitter list will be updated, but new emiters will not be
+             added to the cloud
+
+        Returns
+        -------
+        abundances : class abundanceDict
+             an abundanceDict giving the abundances as a function of time
+        time : array of floats
+             array of output times, in sec
+
+        Raises
+        ------
+        despoticError, if network is None and the cloud does not already
+        have a defined chemical network associated with it
+        """
+
+        return chemEvol(self, tFin, tInit=tInit, nOut=nOut,
+                        dt=dt, tOut=tOut, network=network, info=info,
+                        addEmitters=addEmitters)
+
+
 ########################################################################
 # End of class gasProp
 ########################################################################
