@@ -244,7 +244,7 @@ class emitterData:
                         fetchLamda(os.path.basename(fileName), \
                                        path='', \
                                        fileName=fileName)
-                        fp.open(fileName, 'r')
+                        fp = open(fileName, 'r')
                 # Now read
                 self.readLamda(fp, extrap=extrap)
                 fp.close()
